==> nextcloud-13.0.1.tgz: nextcloud/apps/systemtags/l10n/ka_GE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "ტეგები",
    "Update" : "განახლება",
    "Create" : "შექმნა",
    "Select tag…" : "ტეგის არჩევა…",
    "Tagged files" : "დატაგული ფაილები",
    "Select tags to filter by" : "ფილტრაციისთვის აირჩიეთ ტეგები",
    "No tags found" : "ტეგები ვერ მოიძებნა",
    "Please select tags to filter by" : "ფილტრაციისთვის გთხოვთ აირჩიოთ ტეგები",
    "No files found for the selected tags" : "არჩეული ტეგების მიხედვით ფაილების პოვნა ვერ მოხერხდა",
    "Added system tag %1$s" : "სისტემური ტეგის დამატება %1$s",
    "Added system tag {systemtag}" : "სისტემური ტეგის დამატება {systemtag}",
    "%1$s added system tag %2$s" : " %1$s მომხმარებელმა დაამატა სისტემური ტეგი %2$s",
    "{actor} added system tag {systemtag}" : "{actor} მომხმარებელმა დაამატა სისტემური ტეგი {systemtag}",
    "Removed system tag %1$s" : "გაუქმდა სისტემური ტეგი %1$s",
    "Removed system tag {systemtag}" : "გაუქმდა სისტემური ტეგი {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s მომხმარებელმა გააუქმა სისტემური ტეგი %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} მომხმარებელმა გააუქმა სისტემური ტეგი {systemtag}",
    "You created system tag %1$s" : "თქვენ შექმენით სისტემური ტეგი %1$s",
    "You created system tag {systemtag}" : "თქვენ შექმენით სისტემური ტეგი {systemtag}",
    "%1$s created system tag %2$s" : "%1$s მომხმარებელმა შექმნა სისტემური ტეგი %2$s",
    "{actor} created system tag {systemtag}" : "{actor} მომხმარებლემა შექმნმა სისტემური ტეგი {systemtag}",
    "You deleted system tag %1$s" : "თქვენ გააუქმეთ სისტემური ტეგი %1$s",
    "You deleted system tag {systemtag}" : "თქვენ გააუქმეთ სისტემური ტეგი {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s მომხმარებელმა გააუქმა სისტემური ტეგი %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} მომხმარებელმა გააუქმა სისტემური ტეგი {systemtag}",
    "You updated system tag %2$s to %1$s" : "სისტემური ტეგი %2$s განაახლეთ %1$s-ზე",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "სისტემური ტეგი {oldsystemtag} განაახლეთ {newsystemtag}-ზე",
    "%1$s updated system tag %3$s to %2$s" : "%1$s მომხმარებელმა სისტემური ტეგი %3$s განაახლა %2$s-ზე",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} მომხმარებელმა სისტემური ტეგი {oldsystemtag} განაახლა {newsystemtag}-ზე",
    "You added system tag %2$s to %1$s" : "თქვენ %1$s ფაილს დაუმატეთ სისტემური ტეგი %2$s",
    "You added system tag {systemtag} to {file}" : "თქვენ {file} ფაილს დაუმატეთ სისტემური ტეგი {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s მომხმარებელმა სისტემური ტეგი %3$s დაუმატა ფაილს %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} მომხმარებელმა სისტემური ტეგი {systemtag} დაუმატა ფაილს {file}",
    "You removed system tag %2$s from %1$s" : "თქვენ სისტემური ტეგი %2$s მოაშორეთ ფაილს %1$s",
    "You removed system tag {systemtag} from {file}" : "თქვენ სისტემური ტეგი {systemtag} მოაშორეთ ფაილს {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s მომხმარებელმა სისტემური ტეგი %3$s მოაშორა ფაილს %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} მომხმარებელმა სისტემური ტეგი {systemtag} მოაშორა ფაილს {file}",
    "%s (restricted)" : "%s (აკრძალული)",
    "%s (invisible)" : "%s (უჩინარი)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>სისტემური ტეგები</strong> ფაილისთვის შეიცვალა",
    "Collaborative tags" : "თანამშრომლობის ტეგები",
    "Create and edit collaborative tags. These tags affect all users." : "შეგიძლიათ შექმნათ და შეცვალოთ თანამშრომლობის ტეგები. ეს ტეგები ეხება ყველა მომხმარებელს.",
    "Select tag …" : "ტეგის არჩევა …",
    "Name" : "სახელი",
    "Delete" : "გაუქმება",
    "Public" : "ღია",
    "Restricted" : "აკრძალული",
    "Invisible" : "უჩინარი",
    "Reset" : "საწყის მდომგარეობაში დაბრუნება",
    "No files in here" : "აქ ფაილები არაა",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანების მოძებნა ვერ მოხერხდა",
    "Size" : "ზომა",
    "Modified" : "შეცვლილია"
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.5.tgz: nextcloud/apps/systemtags/l10n/ka_GE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "ტეგები",
    "Update" : "განახლება",
    "Create" : "შექმნა",
    "Select tag…" : "ტეგის არჩევა…",
    "Added system tag {systemtag}" : "სისტემური ტეგის დამატება {systemtag}",
    "Added system tag %1$s" : "სისტემური ტეგის დამატება %1$s",
    "%1$s added system tag %2$s" : " %1$s მომხმარებელმა დაამატა სისტემური ტეგი %2$s",
    "{actor} added system tag {systemtag}" : "{actor} მომხმარებელმა დაამატა სისტემური ტეგი {systemtag}",
    "Removed system tag {systemtag}" : "გაუქმდა სისტემური ტეგი {systemtag}",
    "Removed system tag %1$s" : "გაუქმდა სისტემური ტეგი %1$s",
    "%1$s removed system tag %2$s" : "%1$s მომხმარებელმა გააუქმა სისტემური ტეგი %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} მომხმარებელმა გააუქმა სისტემური ტეგი {systemtag}",
    "You created system tag %1$s" : "თქვენ შექმენით სისტემური ტეგი %1$s",
    "You created system tag {systemtag}" : "თქვენ შექმენით სისტემური ტეგი {systemtag}",
    "%1$s created system tag %2$s" : "%1$s მომხმარებელმა შექმნა სისტემური ტეგი %2$s",
    "{actor} created system tag {systemtag}" : "{actor} მომხმარებლემა შექმნმა სისტემური ტეგი {systemtag}",
    "You deleted system tag %1$s" : "თქვენ გააუქმეთ სისტემური ტეგი %1$s",
    "You deleted system tag {systemtag}" : "თქვენ გააუქმეთ სისტემური ტეგი {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s მომხმარებელმა გააუქმა სისტემური ტეგი %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} მომხმარებელმა გააუქმა სისტემური ტეგი {systemtag}",
    "You updated system tag %2$s to %1$s" : "სისტემური ტეგი %2$s განაახლეთ %1$s-ზე",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "სისტემური ტეგი {oldsystemtag} განაახლეთ {newsystemtag}-ზე",
    "%1$s updated system tag %3$s to %2$s" : "%1$s მომხმარებელმა სისტემური ტეგი %3$s განაახლა %2$s-ზე",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} მომხმარებელმა სისტემური ტეგი {oldsystemtag} განაახლა {newsystemtag}-ზე",
    "You added system tag %2$s to %1$s" : "თქვენ %1$s ფაილს დაუმატეთ სისტემური ტეგი %2$s",
    "You added system tag {systemtag} to {file}" : "თქვენ {file} ფაილს დაუმატეთ სისტემური ტეგი {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s მომხმარებელმა სისტემური ტეგი %3$s დაუმატა ფაილს %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} მომხმარებელმა სისტემური ტეგი {systemtag} დაუმატა ფაილს {file}",
    "You removed system tag %2$s from %1$s" : "თქვენ სისტემური ტეგი %2$s მოაშორეთ ფაილს %1$s",
    "You removed system tag {systemtag} from {file}" : "თქვენ სისტემური ტეგი {systemtag} მოაშორეთ ფაილს {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s მომხმარებელმა სისტემური ტეგი %3$s მოაშორა ფაილს %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} მომხმარებელმა სისტემური ტეგი {systemtag} მოაშორა ფაილს {file}",
    "%s (restricted)" : "%s (აკრძალული)",
    "%s (invisible)" : "%s (უჩინარი)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>სისტემური ტეგები</strong> ფაილისთვის შეიცვალა",
    "Collaborative tags" : "თანამშრომლობის ტეგები",
    "Tagged files" : "დატაგული ფაილები",
    "Select tags to filter by" : "ფილტრაციისთვის აირჩიეთ ტეგები",
    "No tags found" : "ტეგები ვერ მოიძებნა",
    "Please select tags to filter by" : "ფილტრაციისთვის გთხოვთ აირჩიოთ ტეგები",
    "No files found for the selected tags" : "არჩეული ტეგების მიხედვით ფაილების პოვნა ვერ მოხერხდა",
    "Select tag …" : "ტეგის არჩევა …",
    "Name" : "სახელი",
    "Public" : "ღია",
    "Restricted" : "აკრძალული",
    "Invisible" : "უჩინარი",
    "Delete" : "გაუქმება",
    "Reset" : "საწყის მდომგარეობაში დაბრუნება",
    "No files in here" : "აქ ფაილები არაა",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანების მოძებნა ვერ მოხერხდა",
    "Size" : "ზომა",
    "Modified" : "შეცვლილია"
},
"nplurals=2; plural=(n!=1);");
